From: Ville Syrjälä <ville.syrj...@linux.intel.com>

MODE_UNVERIFIED actually means that the mode came from a previous probe,
and if the new probe doesn't produce a matching mode it will get pruned
from the list. Rename the flag to MODE_STALE to better convey the
meaning.

Cc: Adam Jackson <ajax at redhat.com>
Signed-off-by: Ville Syrjälä <ville.syrjala at linux.intel.com>
---
 drivers/gpu/drm/drm_modes.c        | 2 +-
 drivers/gpu/drm/drm_probe_helper.c | 4 ++--
 include/drm/drm_modes.h            | 2 +-
 3 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/drivers/gpu/drm/drm_modes.c b/drivers/gpu/drm/drm_modes.c
index 5f79b9334a38..824125b3337f 100644
--- a/drivers/gpu/drm/drm_modes.c
+++ b/drivers/gpu/drm/drm_modes.c
@@ -1073,7 +1073,7 @@ static const char * const drm_mode_status_names[] = {
        MODE_STATUS(ONE_SIZE),
        MODE_STATUS(NO_REDUCED),
        MODE_STATUS(NO_STEREO),
-       MODE_STATUS(UNVERIFIED),
+       MODE_STATUS(STALE),
        MODE_STATUS(BAD),
        MODE_STATUS(ERROR),
 };
diff --git a/include/drm/drm_modes.h b/include/drm/drm_modes.h
index f9115aee43f4..71801229ce9d 100644
--- a/include/drm/drm_modes.h
+++ b/include/drm/drm_modes.h
@@ -72,7 +72,7 @@ enum drm_mode_status {
     MODE_ONE_SIZE,      /* only one resolution is supported */
     MODE_NO_REDUCED,    /* monitor doesn't accept reduced blanking */
     MODE_NO_STEREO,    /* stereo modes not supported */
-    MODE_UNVERIFIED = -3, /* mode needs to reverified */
+    MODE_STALE = -3,   /* mode has become stale */
     MODE_BAD = -2,     /* unspecified reason */
     MODE_ERROR = -1    /* error condition */
 };
diff --git a/drivers/gpu/drm/drm_probe_helper.c 
b/drivers/gpu/drm/drm_probe_helper.c
index b9b3bd9349ff..2e0c8bfacd35 100644
--- a/drivers/gpu/drm/drm_probe_helper.c
+++ b/drivers/gpu/drm/drm_probe_helper.c
@@ -143,9 +143,9 @@ static int 
drm_helper_probe_single_connector_modes_merge_bits(struct drm_connect

        DRM_DEBUG_KMS("[CONNECTOR:%d:%s]\n", connector->base.id,
                        connector->name);
        /* set all modes to the unverified state */
        list_for_each_entry(mode, &connector->modes, head)
-               mode->status = MODE_UNVERIFIED;
+               mode->status = MODE_STALE;

        old_status = connector->status;
@@ -143,9 +143,9 @@ static int 
        DRM_DEBUG_KMS("[CONNECTOR:%d:%s]\n", connector->base.id,
                        connector->name);
-       /* set all modes to the unverified state */
+       /* set all old modes to the stale state */
        list_for_each_entry(mode, &connector->modes, head)

-- 
2.4.10

Reply via email to